<?php

  /*

   HtPasswd File Reader with Abilities

   -- Copyright --
   Copyright 2004, by James McDuffie (ttq3sxl02@sneakemail.com)

   -- License --
   GNU GPL

   -- Description --

   This class implements reading of a .htpasswd file. It simply reads in
   three field from the file separated by the ':' character:
      username:password:abilities
   The password is encrypted in the usual Apache htpasswd file way. The
   abilites are a comma separated list of actions the user can perform.
   
   -- Example Usage --

   $ht_obj = new HtPasswd('/tmp/.htpasswd');
   $fred_password = $ht_obj->GetUserPassword('fred');
   $fred_can_read = $ht_obj->UserHasAbility('fred', 'read');

  */

define(HTPASSWD_CLASS, '0.1'); 

Class HtPasswd {

  # user_passwords - An array hash where the key is the username and value 
  # the password
  #
  # user_abilites - An array hash where the key is the username and the value
  # is an array of ability strings
  var $user_passwords = array();
  var $user_abilities = array();

  function HtPasswd($htpasswd_file) {

    if(!file_exists($htpasswd_file)) {
      trigger_error("userauth htpasswd file does not exist!");
    }

    @$pwd_file_contents = split("\n", file_get_contents($htpasswd_file));

    foreach($pwd_file_contents as $file_line) {
      # Skip empty lines
      if($file_line != "") {
      
	list($username, $password, $abilities_str) =
	  preg_split("/\s*:\s*/", $file_line);
	@$abilities = preg_split("/\s*,\s*/", $abilities_str);
      
	$this->user_passwords[$username] = $password;
	$this->user_abilities[$username] = $abilities;
      }
    }

  }
	
  function UserHasAbility($username, $ability) {
    if(array_key_exists($username, $this->user_abilities)) {
      $abilities = $this->user_abilities[$username];

      if(in_array($ability, $abilities)) {
	return true;
      }
    }

    return false;
  }

  function GetUserPassword($username) {
    if(!array_key_exists($username, $this->user_passwords)) {
      return "";
    }

    return $this->user_passwords[$username];
  }

  function GetAllUsers() {
    return array_keys($this->user_abilities);
  }

}

?>